/*******************************************************************************
* File Name          : main.c
* Author             : Martin Thomas, main-skeleton based on code from the
*                      STMicroelectronics MCD Application Team
* Version            : see VERSION_STRING below
* Date               : see VERSION_STRING below
* Description        : Main program body for the SD-Card tests
********************************************************************************
* License: BSD
*******************************************************************************/


/* Includes ------------------------------------------------------------------*/
#include "stm32f10x.h"
#include "platform_config.h"
#include "ili9320.h"

/* Private typedef -----------------------------------------------------------*/
#define BmpHeadSize (54)

/* Private define ------------------------------------------------------------*/

/* Private macro -------------------------------------------------------------*/

/* Private variables ---------------------------------------------------------*/

/* Private function prototypes -----------------------------------------------*/
void RCC_Configuration(void);
void GPIO_Configuration(void);
void NVIC_Configuration(void);

/* Public functions -- -------------------------------------------------------*/

/*******************************************************************************
* Function Name  : main_systick_action
* Description    : operations to be done every 1ms
* Input          : None
* Output         : None
* Return         : None
*  overrides weak SysTick_Handler in startup_stm32*.c
*  When a RAMFUNC every function called from inside the ISR must be
*  reachable. This can be achieved by using compiler-option -mlong-calls
*  which globally enables long-calls. Here this option has not been used
*  instead the unreachable functions GPIO_Set/ResetBits have been replaced
*  by direct register-writes and disk_timerproc has also been attributed
*  as RAMFUNC to be reachable.
*******************************************************************************/
RAMFUNC void SysTick_Handler(void)
{
	static uint16_t cnt=0;
	static uint8_t flip=0, cntdiskio=0;

	if( cnt++ >= 500 ) {
		cnt = 0;
		/* alive sign */
		if ( flip ) {
			// GPIO_SetBits(GPIO_LED, GPIO_Pin_LED2 );
			GPIO_LED->BSRR = GPIO_Pin_LED2;
		} else {
			// GPIO_ResetBits(GPIO_LED, GPIO_Pin_LED2 );
			GPIO_LED->BRR = GPIO_Pin_LED2;
		}
		flip = !flip;
	}
	if ( cntdiskio++ >= 10 ) {
		cntdiskio = 0;
		; /* to be called every 10ms */
	}

	
}

/* Private functions ---------------------------------------------------------*/

/*******************************************************************************
* Function Name  : main
* Description    : Main program
* Input          : None
* Output         : None
* Return         : None
*******************************************************************************/
int main(void)
{
	
	u16 i;
	u8 len = 4;
	u16 StartX;
 
	const  uint8_t wert[4] = {'T','e','s','t'};

 
	/* System Clocks Configuration */
	RCC_Configuration();

	/* NVIC configuration */
	NVIC_Configuration();

	/* Configure the GPIO ports */
	GPIO_Configuration();
	
	/* Setup SysTick Timer for 1 millisecond interrupts, also enables Systick and Systick-Interrupt */
	if (SysTick_Config(SystemCoreClock / 1000))
	//if (SysTick_Config(SystemFrequency / 1000))
	{
		/* Capture error */
		while (1);
	}

	// Display initalisieren
	ili9320_Initializtion();
	
	StartX = (320 - 16*len)/2;
	
	
	// funktioniert !
	ili9320_PutChar((StartX+8*0),120,wert[0],Black, Green);
	ili9320_PutChar((StartX+8*1),120,wert[1],Black, Green);
	ili9320_PutChar((StartX+8*2),120,wert[2],Black, Green);
	ili9320_PutChar((StartX+8*3),120,wert[3],Black, Green);
	
	// funktioniert nicht !
    for (i=0;i<4;i++)
    { 
		ili9320_PutChar((StartX+8*i),120,wert[i],Black, Green);
	}
}


/*******************************************************************************
* Function Name  : RCC_Configuration
* Description    : Configures the different system clocks.
* Input          : None
* Output         : None
* Return         : None
*******************************************************************************/
void RCC_Configuration(void)
{
  /* Setup the microcontroller system. Initialize the Embedded Flash Interface,
     initialize the PLL and update the SystemFrequency variable. */
  SystemInit();

  
  /* Enable GPIOA and GPIOD  clocks */
  RCC_APB2PeriphClockCmd(RCC_APB2Periph_GPIOA |RCC_APB2Periph_GPIOx , ENABLE);
  
  
  /* Enable GPIO_LED clock */
  RCC_APB2PeriphClockCmd(RCC_APB2Periph_GPIO_LED, ENABLE);

  
}

/*******************************************************************************
* Function Name  : GPIO_Configuration
* Description    : Configures the different GPIO ports.
* Input          : None
* Output         : None
* Return         : None
*******************************************************************************/
void GPIO_Configuration(void)
{
  GPIO_InitTypeDef GPIO_InitStructure;

  /* Configure GPIO for LEDs as Output push-pull */
  GPIO_InitStructure.GPIO_Pin = GPIO_Pin_LED1 | GPIO_Pin_LED2 ;
  GPIO_InitStructure.GPIO_Speed = GPIO_Speed_50MHz;
  GPIO_InitStructure.GPIO_Mode = GPIO_Mode_Out_PP;
  GPIO_Init(GPIO_LED, &GPIO_InitStructure);


}

/*******************************************************************************
* Function Name  : NVIC_Configuration
* Description    : Configures Vector Table base location.
* Input          : None
* Output         : None
* Return         : None
*******************************************************************************/
#ifdef VECT_TAB_RAM
/* vector-offset (TBLOFF) from bottom of SRAM. defined in linker script */
extern uint32_t _isr_vectorsram_offs;
void NVIC_Configuration(void)
{
  /* Set the Vector Table base location at 0x20000000+_isr_vectorsram_offs */
  NVIC_SetVectorTable(NVIC_VectTab_RAM, (uint32_t)&_isr_vectorsram_offs);
}
#else
extern uint32_t _isr_vectorsflash_offs;
void NVIC_Configuration(void)
{
  /* Set the Vector Table base location at 0x08000000+_isr_vectorsflash_offs */
  NVIC_SetVectorTable(NVIC_VectTab_FLASH, (uint32_t)&_isr_vectorsflash_offs);
}
#endif /* VECT_TAB_RAM */



/*******************************************************************************
* Function Name  : assert_failed
* Description    : called on failed assertion if compiled with USE_FULL_ASSERT
* Input          : pointers to char-arrays/strings: filename, function-name,
*                  line in file
* Output         : via xprintf
* Return         : None
*******************************************************************************/
#ifdef USE_FULL_ASSERT



/**
  * @brief  Reports the name of the source file and the source line number
  *   where the assert_param error has occurred.
  * @param file: pointer to the source file name
  * @param line: assert_param error line source number
  * @retval : None
  */
void assert_failed(const uint8_t* file, const uint8_t* function, uint32_t line)
{
  /* User can add his own implementation to report the file name and line number,
     ex: printf("Wrong parameters value: file %s on line %d\r\n", file, line) */

  //xprintf("\n !!! Wrong parameter value detected\n");
  //xprintf(" - file %s\n", file);
  //xprintf(" - function %s\n", function);
  //xprintf(" - line %lu\n", line);

#if 0
  /* Infinite loop */
  while (1)
  {
  }
#endif
}
#endif
